@@ -399,7 +399,7 @@ void imageSetMaker::createAboutDialog() {
     // Only create a new dialog if it hasn't been made yet
     if(aboutDialogExists == false) {
         aboutDialog = new QDialog(this);
-        aboutDialog->setWindowTitle("Image Set Maker 0.2-1" + tr(" for ") + "Nokia N900");
+        aboutDialog->setWindowTitle("Image Set Maker 0.2.1-1" + tr(" for ") + "Nokia N900");
 
         aboutIcon = new QLabel;
         aboutIcon->setPixmap(QPixmap(":/images/imagesetmaker.png"));
